<%@ Page language="C#" %>
<%@ Import Namespace="System.Data" %>
<%@ Import Namespace="System.Text" %>
<%@ Import Namespace="System.Reflection" %>
<script language="C#" runat="server">
    private void ShowConstructors(Type type)
    {
      DataTable constructorsTable = new DataTable();
      constructorsTable.Columns.Add("Constructor", typeof(string));
      constructorsTable.Columns.Add("Parameters", typeof(string));
      MemberInfo[] constructors = type.GetConstructors();
      foreach (ConstructorInfo constructor in constructors)
      {
        DataRow dr = constructorsTable.NewRow();
        dr["Constructor"] = constructor.DeclaringType.Name;
        StringBuilder sb = new StringBuilder();
        ParameterInfo[] pi = constructor.GetParameters();
        sb.Append("( ");
        for (int i=0; i<pi.Length; i++)
        {
          if (i > 0) sb.Append(", ");
          ParameterInfo p = pi[i];
          sb.Append(p.ParameterType.Name);
          sb.Append(" ");
          sb.Append(p.Name);
        }
        sb.Append(" )");
        dr["Parameters"] = sb.ToString();
        constructorsTable.Rows.Add(dr);
      }
      DataView constructorsView = constructorsTable.DefaultView;
      constructorsView.Sort = "Constructor";
      Constructors.DataSource = constructorsView;
      Constructors.DataBind();
    }

    private void ShowFields(Type type)
    {
      DataTable fieldsTable = new DataTable();
      fieldsTable.Columns.Add("Type", typeof(string));
      fieldsTable.Columns.Add("FieldName", typeof(string));
      MemberInfo[] fields = type.GetFields();
      foreach (FieldInfo field in fields)
      {
        DataRow dr = fieldsTable.NewRow();
        dr["Type"] = field.FieldType.Name;
        dr["FieldName"] = field.Name;
        fieldsTable.Rows.Add(dr);
      }
      DataView fieldsView = fieldsTable.DefaultView;
      fieldsView.Sort = "FieldName";
      Fields.DataSource = fieldsView;
      Fields.DataBind();
    }

    private void ShowProperties(Type type)
    {
      DataTable propertiesTable = new DataTable();
      propertiesTable.Columns.Add("Type", typeof(string));
      propertiesTable.Columns.Add("PropertyName", typeof(string));
      MemberInfo[] properties = type.GetProperties();
      foreach (PropertyInfo property in properties)
      {
        DataRow dr = propertiesTable.NewRow();
        dr["Type"] = property.PropertyType.Name;
        dr["PropertyName"] = property.Name;
        propertiesTable.Rows.Add(dr);
      }
      DataView propertiesView = propertiesTable.DefaultView;
      propertiesView.Sort = "PropertyName";
      Properties.DataSource = propertiesView;
      Properties.DataBind();
    }

    private void ShowMethods(Type type)
    {
      DataTable methodsTable = new DataTable();
      methodsTable.Columns.Add("ReturnType", typeof(string));
      methodsTable.Columns.Add("MethodName", typeof(string));
      methodsTable.Columns.Add("Parameters", typeof(string));
      MethodInfo[] methods = type.GetMethods();
      foreach (MethodInfo method in methods)
      {
        DataRow dr = methodsTable.NewRow();
        dr["ReturnType"] = method.ReturnType.Name;
        dr["MethodName"] = method.Name;
        StringBuilder sb = new StringBuilder();
        ParameterInfo[] pi = method.GetParameters();
        sb.Append("( ");
        for (int i=0; i<pi.Length; i++)
        {
          if (i > 0) sb.Append(", ");
          ParameterInfo p = pi[i];
          sb.Append(p.ParameterType.Name);
          sb.Append(" ");
          sb.Append(p.Name);
        }
        sb.Append(" )");
        dr["Parameters"] = sb.ToString();
        methodsTable.Rows.Add(dr);
      }
      DataView methodsView = methodsTable.DefaultView;
      methodsView.Sort = "MethodName, Parameters";
      Methods.DataSource = methodsView;
      Methods.DataBind();
    }

    private void RetrieveInfo_Click(object sender, System.EventArgs e)
    {
      string selectedClass = ListOfClass.SelectedItem.Value;
      OutputClass.Text = selectedClass;
      Type type = Type.GetType(selectedClass);
      ShowConstructors(type);
      ShowFields(type);
      ShowProperties(type);
      ShowMethods(type);
    }
</script>
<html>
	<head>
		<title>Reflect Class</title>
	</head>
	<body>
		<form id="ReflectClass" method="post" runat="server">
			<table cellSpacing="1" cellPadding="1">
				<tr>
					<td vAlign="top"><asp:button id="RetrieveInfo" onclick="RetrieveInfo_Click" runat="server" Text=" Retrieve Class Info "></asp:button></td>
					<td vAlign="top"><asp:radiobuttonlist id="ListOfClass" runat="server">
							<asp:ListItem Value="System.String"></asp:ListItem>
							<asp:ListItem Value="System.Double"></asp:ListItem>
							<asp:ListItem Value="System.DateTime"></asp:ListItem>
							<asp:ListItem Value="System.Collections.ArrayList"></asp:ListItem>
							<asp:ListItem Value="System.IO.StreamReader"></asp:ListItem>
						</asp:radiobuttonlist></td>
				</tr>
			</table>
			<br>
			<asp:label id="OutputClass" runat="server" Font-Bold="True" Font-Size="Larger"></asp:label><br>
			<br>
			<strong>Constructors</strong>
			<br>
			<asp:datagrid id="Constructors" runat="server" BorderColor="#999999" BorderStyle="Solid" BorderWidth="1px" BackColor="White" CellPadding="3" GridLines="Vertical" ForeColor="Black">
				<AlternatingItemStyle BackColor="#CCCCCC"></AlternatingItemStyle>
				<HeaderStyle Font-Bold="True" ForeColor="White" BackColor="Black"></HeaderStyle>
			</asp:datagrid>
			<br>
			<strong>Fields</strong>
			<br>
			<asp:datagrid id="Fields" runat="server" BorderColor="#999999" BorderStyle="Solid" BorderWidth="1px" BackColor="White" CellPadding="3" GridLines="Vertical" ForeColor="Black">
				<AlternatingItemStyle BackColor="#CCCCCC"></AlternatingItemStyle>
				<HeaderStyle Font-Bold="True" ForeColor="White" BackColor="Black"></HeaderStyle>
			</asp:datagrid><br>
			<strong>Properties</strong>
			<br>
			<asp:datagrid id="Properties" runat="server" BorderColor="#999999" BorderStyle="Solid" BorderWidth="1px" BackColor="White" CellPadding="3" GridLines="Vertical" ForeColor="Black">
				<AlternatingItemStyle BackColor="#CCCCCC"></AlternatingItemStyle>
				<HeaderStyle Font-Bold="True" ForeColor="White" BackColor="Black"></HeaderStyle>
			</asp:datagrid><br>
			<strong>Methods</strong>
			<br>
			<asp:datagrid id="Methods" runat="server" BorderColor="#999999" BorderStyle="Solid" BorderWidth="1px" BackColor="White" CellPadding="3" GridLines="Vertical" ForeColor="Black">
				<AlternatingItemStyle BackColor="#CCCCCC"></AlternatingItemStyle>
				<HeaderStyle Font-Bold="True" ForeColor="White" BackColor="Black"></HeaderStyle>
			</asp:datagrid>
		</form>
	</body>
</html>
